@@ -13,7 +13,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2002-2019  Craig Barratt
+#   Copyright (C) 2002-2020  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #
 #========================================================================
 #
-# Version 4.3.1, released 14 Jul 2019.
+# Version 4.3.2, released 17 Feb 2020.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -62,15 +62,16 @@ sub start
     my $conf = $t->{conf};
     my(@fileList, $rsyncArgs, $logMsg, $rsyncCmd);
     my $binDir = $t->{bpc}->BinDir();
+    my $shareNamePath = $t->shareName2Path($t->{shareName});
 
     alarm(0);
     #
     # We add a slash to the share name we pass to rsync
     #
-    ($t->{shareNameSlash} = "$t->{shareName}/") =~ s{//+$}{/};
+    ($t->{shareNameSlash} = "$shareNamePath/") =~ s{//+$}{/};
 
     if ( $t->{type} eq "restore" ) {
-	my $remoteDir = "$t->{shareName}/$t->{pathHdrDest}";
+	my $remoteDir = "$shareNamePath/$t->{pathHdrDest}";
 	$remoteDir    =~ s{//+}{/}g;
         my $filesFd;
         my $srcList;
@@ -144,7 +145,7 @@ sub start
                     return;
                 }
             }
-            my $shareName = $t->{shareName};
+            #my $shareName = $t->{shareName};
             #from_to($shareName, "utf8", $conf->{ClientCharset})
             #                    if ( $conf->{ClientCharset} ne "" );
             if ( $conf->{RsyncdClientPort} != 873 ) {
@@ -162,12 +163,13 @@ sub start
         # Merge variables into $rsyncArgs
         #
         $rsyncArgs = $bpc->cmdVarSubstitute($rsyncArgs, {
-                            host      => $t->{host},
-                            hostIP    => $t->{hostIP},
-                            client    => $t->{client},
-			    shareName => $t->{shareName},
-                            confDir   => $conf->{ConfDir},
-                            sshPath   => $conf->{SshPath},
+                            host          => $t->{host},
+                            hostIP        => $t->{hostIP},
+                            client        => $t->{client},
+                            shareNameOrig => $t->{shareName},
+                            shareName     => $shareNamePath,
+                            confDir       => $conf->{ConfDir},
+                            sshPath       => $conf->{SshPath},
                         });
         #
         # create --bpc-bkup-merge list.  This is the list of backups that have to
@@ -320,11 +322,16 @@ sub start
             $logMsg = "full backup started for directory $t->{shareName}";
             if ( ref($conf->{RsyncFullArgsExtra}) eq 'ARRAY' ) {
                 push(@$rsyncArgs, @{$conf->{RsyncFullArgsExtra}});
-            } else {
+            } elsif ( ref($conf->{RsyncFullArgsExtra}) eq '' && $conf->{RsyncFullArgsExtra} ne "" ) {
                 push(@$rsyncArgs, $conf->{RsyncFullArgsExtra});
             }
         } else {
             $logMsg = "incr backup started for directory $t->{shareName}";
+            if ( ref($conf->{RsyncIncrArgsExtra}) eq 'ARRAY' ) {
+                push(@$rsyncArgs, @{$conf->{RsyncIncrArgsExtra}});
+            } elsif ( ref($conf->{RsyncIncrArgsExtra}) eq '' && $conf->{RsyncIncrArgsExtra} ne "" ) {
+                push(@$rsyncArgs, $conf->{RsyncIncrArgsExtra});
+            }
         }
         
         #
@@ -354,12 +361,13 @@ sub start
         # Merge variables into $rsyncArgs
         #
         $rsyncArgs = $bpc->cmdVarSubstitute($rsyncArgs, {
-                            host      => $t->{host},
-                            hostIP    => $t->{hostIP},
-                            client    => $t->{client},
-			    shareName => $t->{shareName},
-                            confDir   => $conf->{ConfDir},
-                            sshPath   => $conf->{SshPath},
+                            host          => $t->{host},
+                            hostIP        => $t->{hostIP},
+                            client        => $t->{client},
+                            shareNameOrig => $t->{shareName},
+                            shareName     => $shareNamePath,
+                            confDir       => $conf->{ConfDir},
+                            sshPath       => $conf->{SshPath},
                         });
 
         if ( $t->{XferMethod} eq "rsync" ) {
@@ -388,7 +396,7 @@ sub start
                 $t->{_errStr} = "Failed to open/create rsynd pw file $t->{pwFile}";
                 return;
             }
-            my $shareName = $t->{shareName};
+            my $shareName = $shareNamePath;
             #from_to($shareName, "utf8", $conf->{ClientCharset})
             #                    if ( $conf->{ClientCharset} ne "" );
             push(@$rsyncArgs, @fileList) if ( @fileList );
@@ -421,6 +429,7 @@ sub start
             '--bpc-log-level',      $conf->{XferLogLevel},
         );
     }
+    $logMsg .= " (client path $shareNamePath)" if ( $t->{shareName} ne $shareNamePath );
 
     #from_to($args->{shareName}, "utf8", $conf->{ClientCharset})
     #                        if ( $conf->{ClientCharset} ne "" );
